@@ -1,13 +1,7 @@
 use std::io::Cursor;
 
-use rmp_serde::{
-  Deserializer,
-  Serializer,
-};
-use serde::{
-  Deserialize,
-  Serialize,
-};
+use rmp_serde::{Deserializer, Serializer};
+use serde::{Deserialize, Serialize};
 
 use crate::error::CodecError;
 use crate::Result;
@@ -18,7 +12,11 @@ where
   T: ?Sized + Serialize,
 {
   let mut buf = Vec::new();
-  match item.serialize(&mut Serializer::new(&mut buf).with_string_variants()) {
+  match item.serialize(
+    &mut Serializer::new(&mut buf)
+      .with_string_variants()
+      .with_struct_map(),
+  ) {
     Ok(_) => Ok(buf),
     Err(e) => Err(e),
   }
